@@ -16,9 +16,6 @@ class EnumMultiChoiceField(forms.MultipleChoiceField):
 
         super().__init__(*args, choices=self.__choices, **kwargs)
 
-    def to_python(self, value):
-        if not value: return None
-        return [str(val) for val in value]
 
     @property
     def overwritten_type(self):
